@@ -1,5 +1,6 @@
 #include "PowerMenuEntryCreator.h"
 #include <QDebug>
+#include <QSettings>
 
 QXmlStreamWriter& PowerMenuEntryCreator::writeLaunchAppCallback(QXmlStreamWriter& w)
 {
@@ -59,8 +60,43 @@ QXmlStreamWriter& PowerMenuEntryCreator::writeXTermCommandCallback(QXmlStreamWri
     w.writeEndElement(); // callback
 
     return w;
+}
 
+QXmlStreamWriter& PowerMenuEntryCreator::writeDBusServiceCallback(QXmlStreamWriter &w)
+{
+    QSettings servicefile(argument, QSettings::IniFormat);
+    servicefile.beginGroup("D-Bus Service");
+    if (! servicefile.contains("Name"))
+    {
+        emit malformedFile();
+        throw QChar();
+    }
 
+    QString service = servicefile.value("Name").toString();
+    QString service_path = service;
+
+    QXmlStreamAttributes atr;
+    atr.append("service", service);
+    atr.append("path", "/" + service_path.replace('.', '/'));
+    atr.append("interface", service);
+    atr.append("method", "top_application");
+    atr.append("bus", "session");
+    atr.append("autostart", "true");
+
+    w.writeStartElement("callback");
+    w.writeAttributes(atr);
+
+    if (!dbusArg.isEmpty())
+    {
+        w.writeStartElement("argument");
+        w.writeAttribute("type", "string");
+        w.writeCharacters(dbusArg);
+        w.writeEndElement(); // argument
+    }
+
+    w.writeEndElement(); // callback
+
+    return w;
 }
 
 bool PowerMenuEntryCreator::createEntry()
@@ -87,10 +123,19 @@ bool PowerMenuEntryCreator::createEntry()
         writer.writeTextElement("icon", iconUrl);
     }
 
-    switch (entry)
+    try
     {
-    case LaunchApp: writeLaunchAppCallback(writer);
-    case XTermCommand: writeXTermCommandCallback(writer);
+        switch (entry)
+        {
+        case LaunchApp: writeLaunchAppCallback(writer);
+        case XTermCommand: writeXTermCommandCallback(writer);
+        case DBusService: writeDBusServiceCallback(writer);
+        }
+    }
+    catch (QChar)
+    {
+        //file.remove();
+        return false;
     }
 
 
@@ -99,7 +144,12 @@ bool PowerMenuEntryCreator::createEntry()
     writer.writeEndElement(); // powerkeymenu
 
     file.close();
-    if (file.error() != QFile::NoError) return false;
+    if (file.error() != QFile::NoError)
+    {
+        //file.remove();
+        emit writeError();
+        return false;
+    }
     else return true;
 }
 
