@@ -20,10 +20,12 @@ public:
     Q_PROPERTY(QString iconUrl READ getIconUrl WRITE setIconUrl NOTIFY iconChanged)
     Q_PROPERTY(QString appName READ getAppName WRITE setAppName NOTIFY appNameChanged)
     Q_PROPERTY(EntryType entry READ getEntryType WRITE setEntryType NOTIFY entryTypeChanged)
+    Q_PROPERTY(QString dbusArg READ getDbusArg WRITE setDbusArg NOTIFY dbusArgChanged)
     enum EntryType
     {
         LaunchApp = 0,
-        XTermCommand = 1
+        XTermCommand = 1,
+        DBusService = 2
     } entry;
 
     PowerMenuEntryCreator() : entry(LaunchApp), priority(500) {}
@@ -35,14 +37,15 @@ public:
     Q_INVOKABLE bool createEntry();
     //Q_INVOKABLE inline void setData(desktopDescriptor d) {appName = d.getAppName(); desktopName = d.getDesktop(); iconUrl = d.getIcon(); }
     Q_INVOKABLE inline void setData(QString an, QString dn, QString iu) {appName = an; argument = dn; iconUrl = iu;}
-    inline QString stripFilename(QString filename) const { return QFileInfo(filename).baseName(); }
+    static inline QString stripFilename(const QString filename) { return QFileInfo(filename).baseName(); }
 
 protected:
     int priority;
     QString argument, appName, // name visible to user and name of .desktop
-            iconUrl;
+            iconUrl, dbusArg;
     QXmlStreamWriter& writeLaunchAppCallback(QXmlStreamWriter& w);
     QXmlStreamWriter& writeXTermCommandCallback(QXmlStreamWriter& w);
+    QXmlStreamWriter& writeDBusServiceCallback(QXmlStreamWriter& w);
     QString entryFileName() const;
 
     inline int getPriority() const {return priority;}
@@ -51,12 +54,14 @@ protected:
     inline QString getIconUrl() const { return iconUrl; }
     inline QString getAppName() const {return appName; }
     inline EntryType getEntryType() const { return entry; }
+    inline QString getDbusArg() const {return dbusArg; }
 
     inline void setPriority(int p) { priority = p; emit priorityChanged(p); }
     inline void setArgument(QString n) { argument = n; emit argumentChanged(n); }
     inline void setIconUrl(QString u) { iconUrl = u; emit iconChanged(u); }
     inline void setAppName(QString a) { appName = a; emit appNameChanged(a); }
     inline void setEntryType(EntryType type) { entry = type; emit entryTypeChanged(type); }
+    inline void setDbusArg(QString ar) { dbusArg = ar; emit dbusArgChanged(ar); }
 
 signals:
     void priorityChanged(int p);
@@ -64,6 +69,9 @@ signals:
     void iconChanged(QString i);
     void appNameChanged(QString a);
     void entryTypeChanged(EntryType e);
+    void dbusArgChanged(QString arg);
+    void malformedFile();
+    void writeError();
 };
 
 #endif // POWERMENUENTRYCREATOR_H
